summaryrefslogtreecommitdiffstats
path: root/src/usr/errl
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/errl')
-rw-r--r--src/usr/errl/errlentry.C12
1 files changed, 8 insertions, 4 deletions
diff --git a/src/usr/errl/errlentry.C b/src/usr/errl/errlentry.C
index 2cc64faf1..20d6782f1 100644
--- a/src/usr/errl/errlentry.C
+++ b/src/usr/errl/errlentry.C
@@ -1658,16 +1658,20 @@ uint64_t ErrlEntry::unflatten( const void * i_buffer, uint64_t i_len )
}
//@brief Return the list of User Detail sections
-//NOTE: You can pass COMP_ID 0 into this function for wildcard
-std::vector<ErrlUD*> ErrlEntry::getUDSections(compId_t i_compId)
+//NOTE: You can pass COMP_ID or subsect 0 into this function for wildcard
+std::vector<void*> ErrlEntry::getUDSections(compId_t i_compId,
+ uint8_t i_subSect)
{
- std::vector<ErrlUD*> copy_vector;
+ std::vector<void *> copy_vector;
for(auto const & section : iv_SectionVector)
{
if((section->compId() == i_compId) || (i_compId == 0))
{
- copy_vector.push_back(section);
+ if((section->subSect() == i_subSect) || (i_subSect == 0))
+ {
+ copy_vector.push_back(section->iv_pData);
+ }
}
}
OpenPOWER on IntegriCloud